#[repr(C, align(16))]pub struct Trapframe {
pub regs: IntRegisters,
pub epc: u64,
pub _padding: u64,
}Fields
regs: IntRegistersepc: u64_padding: u64Implementations
Sourceimpl Trapframe
impl Trapframe
pub fn new() -> Self
pub fn get_syscall_number(&self) -> usize
pub fn set_syscall_number(&mut self, syscall_number: usize)
pub fn get_return_value(&self) -> usize
pub fn set_return_value(&mut self, value: usize)
pub fn get_arg(&self, index: usize) -> usize
pub fn set_arg(&mut self, index: usize, value: usize)
pub fn get_current_pc(&self) -> u64
Sourcepub fn increment_pc_next(&mut self, task: &Task)
pub fn increment_pc_next(&mut self, task: &Task)
Increment the program counter (epc) to the next instruction This is typically used after handling a trap or syscall to continue execution.