pub fn first_switch_to_user(task: &mut Task) -> !Expand description
RISC-V: perform the very first transition into a runnable user task.
This avoids bootstrapping the first user entry via a timer IRQ.
The function prepares trampoline-visible per-CPU state and then
jumps to the trampoline exit path which performs sret into user mode.